MapDistribution — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- MapDistribution

# MapDistribution

class `pysm.` `MapDistribution`(pixel_indices=None, mpi_comm=None, nside=None, smoothing_lmax=None)

  Bases: `object`

  Define how a map is distributed

  In a serial environment, this is only useful if you want to generate a partial sky, pass an array `pixel_indices` with the indices in RING ordering.

  in a MPI environment, pass a `mpi4py` communicator and the desired \(\ell_{max}\) for smoothing and this class will create a ring-based distribution suitable for smoothing with `libsharp`.

  Parameters
    pixel_indicesndarray of integers

      Subset of pixels that should be used in RING ordering

    mpi_comm: object

      MPI communicator object (optional, default=None).

    nside: int

      Resolution parameter at which this model is to be calculated.

    smoothing_lmaxint

      \(\ell_{max}\) for the smoothing step, by default \(3*N_{side}-1\)